@@ -1,11 +1,12 @@
-from .command import CommandOptionType, SlashCommand
-from .context import InteractionContext
+from .command import SlashCommand
+from .context import InteractionContext, CommandOptionType, ChannelType
 from .discord import DiscordInteractions, DiscordInteractionsBlueprint
 from .response import InteractionResponseType, InteractionResponse
 
 
 __all__ = [
     CommandOptionType,
+    ChannelType,
     SlashCommand,
     InteractionContext,
     DiscordInteractions,
